'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _babelTypes = require('babel-types');

var t = _interopRequireWildcard(_babelTypes);

var _ramda = require('ramda');

var R = _interopRequireWildcard(_ramda);

var _generateCode = require('./generateCode');

var _generateCode2 = _interopRequireDefault(_generateCode);

var _moduleExports = require('./moduleExports');

var _moduleExports2 = _interopRequireDefault(_moduleExports);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function getKey(encoded) {
    if (/[0-9]/.test(encoded[0])) {
        return t.stringLiteral(encoded);
    }
    return t.identifier(encoded);
}

var stringify = function stringify(list) {
    return Object.keys(list).reduce(function (ast, key) {
        var data = list[key];
        var value = void 0;
        if (data === null) {
            value = t.nullLiteral();
        } else if (typeof data === 'undefined') {
            value = t.identifier('undefined');
        } else if (typeof data === 'string') {
            value = t.stringLiteral(data);
        } else if (typeof data === 'number') {
            value = t.numericLiteral(data);
        } else if (Array.isArray(data)) {
            value = t.arrayExpression(data.map(function child(d) {
                if (d === null) {
                    return t.nullLiteral();
                }
                if (typeof d === 'undefined') {
                    return t.identifier('undefined');
                }
                if (typeof d === 'string') {
                    return t.stringLiteral(d);
                }
                if (typeof d === 'number') {
                    return t.numericLiteral(d);
                }
                if (Array.isArray(d)) {
                    return t.arrayExpression(d.map(child));
                }
            }));
        } else if (data === Object(data)) {
            value = t.objectExpression(stringify(data));
        }
        return ast.concat(t.objectProperty(getKey(key), value));
    }, []);
};

var stringifyObject = R.compose(_generateCode2.default, t.program, R.of, _moduleExports2.default, t.objectExpression, stringify);

exports.default = stringifyObject;